@@ -1,6 +1,6 @@
 package Net::Google::FederatedLogin;
 BEGIN {
-  $Net::Google::FederatedLogin::VERSION = '0.3.0';
+  $Net::Google::FederatedLogin::VERSION = '0.4.0';
 }
 # ABSTRACT: Google Federated Login module - see http://code.google.com/apis/accounts/docs/OpenID.html
 
@@ -17,6 +17,12 @@ has claimed_id    => (
 );
 
 
+has realm   => (
+    is  => 'rw',
+    isa => 'Str',
+);
+
+
 has ua  => (
     is  => 'rw',
     isa => 'LWP::UserAgent',
@@ -99,6 +105,10 @@ sub _get_request_parameters {
         . '&openid.identity=http://specs.openid.net/auth/2.0/identifier_select'
         . '&openid.return_to=' . $self->return_to;
     
+    if(my $realm = $self->realm) {
+        $params .= '&openid.realm='.$realm;
+    }
+    
     return $params;
 }
 
@@ -171,7 +181,7 @@ Net::Google::FederatedLogin - Google Federated Login module - see http://code.go
 
 =head1 VERSION
 
-version 0.3.0
+version 0.4.0
 
 =head1 ATTRIBUTES
 
@@ -179,6 +189,12 @@ version 0.3.0
 
 B<Required for L<"get_auth_url">:> The email address, or an OpenID URL of the identity to be checked.
 
+=head2 realm
+
+Optional field that is used to populate the openid.realm parameter.
+If not provided the parameter will not be used (as opposed to being
+calculated from the L<"return_to">" value).
+
 =head2 ua
 
 The useragent internally used for communications that the
@@ -215,7 +231,7 @@ successfully verified, it is returned (otherwise a false value is returned).
 
 =head1 AUTHOR
 
-  Glenn Fowler <cebjyre@cpan.org>
+Glenn Fowler <cebjyre@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
